@@ -1,5 +1,5 @@
 package TestML::Compiler::Lite;
-$TestML::Compiler::Lite::VERSION = '0.35';
+
 use TestML::Base;
 extends 'TestML::Compiler';
 
@@ -14,7 +14,7 @@ my $WS = qr!\s+!;
 my $ANY = qr!.!;
 my $STAR = qr!\*!;
 my $NUM = qr!-?[0-9]+!;
-my $WORD = qr!\w+!;
+my $WORD = qr![-\w]+!;
 my $HASH = qr!#!;
 my $EQ = qr!=!;
 my $TILDE = qr!~!;
@@ -35,6 +35,9 @@ my $PUNCT = qr!(?:$LP|$RP|$DOT|$COMMA|$SEMI)!;
 
 my $TOKENS = qr!(?:$POINT|$NUM|$WORD|$QSTR|$PUNCT|$OPER)!;
 
+our $block_marker = '===';
+our $point_marker = '---';
+
 sub compile_code {
     my ($self) = @_;
     $self->{function} = TestML::Function->new;
@@ -123,8 +126,10 @@ sub parse_expression {
         }
         elsif ($token =~ /^$POINT$/) {
             $token =~ /($WORD)/ or die;
-            push @{$self->{points}}, $1;
-            push @$calls, TestML::Point->new(name => $1);
+            $token = $1;
+            $token =~ s/-/_/g;
+            push @{$self->{points}}, $token;
+            push @$calls, TestML::Point->new(name => $token);
         }
         else {
             $self->fail("Unknown token '$token'");
@@ -155,7 +160,7 @@ sub compile_data {
     my $input = $self->data;
     $input =~ s/^#.*\n/\n/mg;
     $input =~ s/^\\//mg;
-    my @blocks = grep $_, split /(^===.*?(?=^===|\z))/ms, $input;
+    my @blocks = grep $_, split /(^$block_marker.*?(?=^$block_marker|\z))/ms, $input;
     for my $block (@blocks) {
         $block =~ s/\n+\z/\n/;
     }
@@ -163,21 +168,28 @@ sub compile_data {
     my $data = [];
     for my $string_block (@blocks) {
         my $block = TestML::Block->new;
-        $string_block =~ s/^===\ +(.*?)\ *\n//g
+        $string_block =~ s/^$block_marker\ +(.*?)\ *\n//g
             or die "No block label! $string_block";
         $block->{label} = $1;
+        $string_block =~ s/\A(.*?)(^$point_marker\ )/$2/sm;
         while (length $string_block) {
             next if $string_block =~ s/^\n+//;
             my ($key, $value);
-            if ($string_block =~ s/\A---\ +(\w+):\ +(.*)\n//g or
-                $string_block =~ s/\A---\ +(\w+)\n(.*?)(?=^---|\z)//msg
+            if ($string_block =~ s/\A$point_marker\ +($WORD):\ +(.*)\n//g or
+                $string_block =~
+                    s/\A$point_marker\ +($WORD)\n(.*?)(?=^$point_marker|\z)//msg
             ) {
                 ($key, $value) = ($1, $2);
+                $key =~ s/-/_/g;
             }
             else {
                 die "Failed to parse TestML string:\n$string_block";
             }
             $block->{points} ||= {};
+            my $eol = ($value =~ s/(\r?\n)\s*\z//) ? $1 : '';
+            if (length $value) {
+                $value .= $eol;
+            }
             $block->{points}{$key} = $value;
 
             if ($key =~ /^(ONLY|SKIP|LAST)$/) {
